@@ -49,23 +49,25 @@ class SaunterWebDriver(webdriver.Remote):
             raise saunter.exceptions.InvalidLocatorString(locator)
         locator_value = locator[locator.find("=") + 1:]
         if locator_type == 'class':
-            return self.find_elements_by_class_name(locator_value)
+            elements = self.find_elements_by_class_name(locator_value)
         elif locator_type == 'css':
-            return self.find_elements_by_css_selector(locator_value)
+            elements = self.find_elements_by_css_selector(locator_value)
         elif locator_type == 'id':
-            return self.find_elements_by_id(locator_value)
+            elements = self.find_elements_by_id(locator_value)
         elif locator_type == 'link':
-            return self.find_elements_by_link_text(locator_value)
+            elements = self.find_elements_by_link_text(locator_value)
         elif locator_type == 'name':
-            return self.find_elements_by_name(locator_value)
+            elements = self.find_elements_by_name(locator_value)
         elif locator_type == 'plink':
-            return self.find_elements_by_partial_link_text(locator_value)
+            elements = self.find_elements_by_partial_link_text(locator_value)
         elif locator_type == 'tag':
-            return self.find_elements_by_tag_name(locator_value)
+            elements = self.find_elements_by_tag_name(locator_value)
         elif locator_type == 'xpath':
-            return self.find_elements_by_xpath(locator_value)
+            elements = self.find_elements_by_xpath(locator_value)
         else:
             raise saunter.exceptions.InvalidLocatorString(locator)
+        
+        return [WebElement(e) for e in elements]
 
     # @deprecated
     @classmethod
